@@ -8,7 +8,11 @@ ui.page_modules <- function() {
     tabPanel("Genomic Analysis"),
     tabPanel(
       "Visualization",
-      ui.modules_pancan_dist("module_gene_pancan_dist")   
+      ui.modules_pancan_dist("module_gene_pancan_dist")
+      ),
+    tabPanel(
+      "Survival analysis",
+      ui.modules_sur_plot("modules_sur_plot")   
     )
   )
 }
